@@ -9,7 +9,6 @@
 #include "sysconfig.h"
 #include "sysdeps.h"
 
-#include "config.h"
 #include "options.h"
 #include "events.h"
 #include "uae.h"
@@ -20,21 +19,19 @@
 #include "blit.h"
 
 uae_u16 oldvblts;
-uae_u16 bltcon0,bltcon1;
-uae_u32 bltapt,bltbpt,bltcpt,bltdpt;
+uae_u16 bltcon0, bltcon1;
+uae_u32 bltapt, bltbpt, bltcpt, bltdpt;
 
 int blinea_shift;
-static uae_u16 blitlpos, blinea, blineb;
-static uaecptr bltcnxlpt,bltdnxlpt;
-static int blitline,blitfc,blitfill,blitife,blitdesc,blitsing;
-static int blitonedot,blitsign;
+static uae_u16 blinea, blineb;
+static int blitline, blitfc, blitfill, blitife, blitsing, blitdesc;
+static int blitonedot, blitsign;
 static long int bltwait;
 
 struct bltinfo blt_info;
 
 static uae_u8 blit_filltable[256][4][2];
 uae_u32 blit_masktable[BLITTER_MAX_WORDS];
-static uae_u16 blit_trashtable[BLITTER_MAX_WORDS];
 enum blitter_states bltstate;
 
 static uae_u8 blit_cycle_diagram_start[][10] =
@@ -57,7 +54,7 @@ static uae_u8 blit_cycle_diagram_start[][10] =
     { 4, 4, 1,2,3,0, 1,2,3,4 }	/* F */
 };
 
-void build_blitfilltable(void)
+void build_blitfilltable (void)
 {
     unsigned int d, fillmask;
     int i;
@@ -85,19 +82,7 @@ void build_blitfilltable(void)
     }
 }
 
-STATIC_INLINE uae_u8 *blit_xlateptr(uaecptr bltpt, int bytecount)
-{
-    if (!chipmem_bank.check(bltpt,bytecount)) return NULL;
-    return chipmem_bank.xlateaddr(bltpt);
-}
-
-STATIC_INLINE uae_u8 *blit_xlateptr_desc(uaecptr bltpt, int bytecount)
-{
-    if (!chipmem_bank.check(bltpt-bytecount, bytecount)) return NULL;
-    return chipmem_bank.xlateaddr(bltpt);
-}
-
-static void blitter_dofast(void)
+static void blitter_dofast (void)
 {
     int i,j;
     uaecptr bltadatptr = 0, bltbdatptr = 0, bltcdatptr = 0, bltddatptr = 0;
@@ -129,6 +114,7 @@ static void blitter_dofast(void)
 	uae_u32 blitbhold = blt_info.bltbhold;
 	uae_u32 preva = 0, prevb = 0;
 	uaecptr dstp = 0;
+	int dodst = 0;
 
 	/*if (!blitfill) write_log ("minterm %x not present\n",mt); */
 	for (j = 0; j < blt_info.vblitsize; j++) {
@@ -136,7 +122,7 @@ static void blitter_dofast(void)
 	    for (i = 0; i < blt_info.hblitsize; i++) {
 		uae_u32 bltadat, blitahold;
 		if (bltadatptr) {
-		    bltadat = chipmem_wget (bltadatptr);
+		    blt_info.bltadat = bltadat = chipmem_agnus_wget (bltadatptr);
 		    bltadatptr += 2;
 		} else
 		    bltadat = blt_info.bltadat;
@@ -145,16 +131,18 @@ static void blitter_dofast(void)
 		preva = bltadat;
 
 		if (bltbdatptr) {
-		    uae_u16 bltbdat = chipmem_wget (bltbdatptr);
+		    uae_u16 bltbdat;
+		    blt_info.bltbdat = bltbdat = chipmem_agnus_wget (bltbdatptr);
 		    bltbdatptr += 2;
 		    blitbhold = (((uae_u32)prevb << 16) | bltbdat) >> blt_info.blitbshift;
 		    prevb = bltbdat;
 		}
 		if (bltcdatptr) {
-		    blt_info.bltcdat = chipmem_wget (bltcdatptr);
+		    blt_info.bltcdat = chipmem_agnus_wget (bltcdatptr);
 		    bltcdatptr += 2;
 		}
-		if (dstp) chipmem_wput (dstp, blt_info.bltddat);
+		if (dodst)
+		    chipmem_agnus_wput (dstp, blt_info.bltddat);
 		blt_info.bltddat = blit_func (blitahold, blitbhold, blt_info.bltcdat, mt) & 0xFFFF;
 		if (blitfill) {
 		    uae_u16 d = blt_info.bltddat;
@@ -167,6 +155,7 @@ static void blitter_dofast(void)
 		if (blt_info.bltddat)
 		    blt_info.blitzero = 0;
 		if (bltddatptr) {
+		    dodst = 1;
 		    dstp = bltddatptr;
 		    bltddatptr += 2;
 		}
@@ -176,7 +165,8 @@ static void blitter_dofast(void)
 	    if (bltcdatptr) bltcdatptr += blt_info.bltcmod;
 	    if (bltddatptr) bltddatptr += blt_info.bltdmod;
 	}
-	if (dstp) chipmem_wput (dstp, blt_info.bltddat);
+	if (dodst)
+	    chipmem_agnus_wput (dstp, blt_info.bltddat);
 	blt_info.bltbhold = blitbhold;
     }
     blit_masktable[0] = 0xFFFF;
@@ -185,7 +175,7 @@ static void blitter_dofast(void)
     bltstate = BLT_done;
 }
 
-static void blitter_dofast_desc(void)
+static void blitter_dofast_desc (void)
 {
     int i,j;
     uaecptr bltadatptr = 0, bltbdatptr = 0, bltcdatptr = 0, bltddatptr = 0;
@@ -216,6 +206,7 @@ static void blitter_dofast_desc(void)
 	uae_u32 blitbhold = blt_info.bltbhold;
 	uae_u32 preva = 0, prevb = 0;
 	uaecptr dstp = 0;
+	int dodst = 0;
 
 /*	if (!blitfill) write_log ("minterm %x not present\n",mt);*/
 	for (j = 0; j < blt_info.vblitsize; j++) {
@@ -223,7 +214,7 @@ static void blitter_dofast_desc(void)
 	    for (i = 0; i < blt_info.hblitsize; i++) {
 		uae_u32 bltadat, blitahold;
 		if (bltadatptr) {
-		    bltadat = chipmem_wget (bltadatptr);
+		    blt_info.bltadat = bltadat = chipmem_agnus_wget (bltadatptr);
 		    bltadatptr -= 2;
 		} else
 		    bltadat = blt_info.bltadat;
@@ -231,16 +222,18 @@ static void blitter_dofast_desc(void)
 		blitahold = (((uae_u32)bltadat << 16) | preva) >> blt_info.blitdownashift;
 		preva = bltadat;
 		if (bltbdatptr) {
-		    uae_u16 bltbdat = chipmem_wget (bltbdatptr);
+		    uae_u16 bltbdat;
+		    blt_info.bltbdat = bltbdat = chipmem_agnus_wget (bltbdatptr);
 		    bltbdatptr -= 2;
 		    blitbhold = (((uae_u32)bltbdat << 16) | prevb) >> blt_info.blitdownbshift;
 		    prevb = bltbdat;
 		}
 		if (bltcdatptr) {
-		    blt_info.bltcdat = chipmem_wget (bltcdatptr);
+		    blt_info.bltcdat = chipmem_agnus_wget (bltcdatptr);
 		    bltcdatptr -= 2;
 		}
-		if (dstp) chipmem_wput (dstp, blt_info.bltddat);
+		if (dodst)
+		    chipmem_agnus_wput (dstp, blt_info.bltddat);
 		blt_info.bltddat = blit_func (blitahold, blitbhold, blt_info.bltcdat, mt) & 0xFFFF;
 		if (blitfill) {
 		    uae_u16 d = blt_info.bltddat;
@@ -253,6 +246,7 @@ static void blitter_dofast_desc(void)
 		if (blt_info.bltddat)
 		    blt_info.blitzero = 0;
 		if (bltddatptr) {
+		    dodst = 1;
 		    dstp = bltddatptr;
 		    bltddatptr -= 2;
 		}
@@ -262,7 +256,8 @@ static void blitter_dofast_desc(void)
 	    if (bltcdatptr) bltcdatptr -= blt_info.bltcmod;
 	    if (bltddatptr) bltddatptr -= blt_info.bltdmod;
 	}
-	if (dstp) chipmem_wput (dstp, blt_info.bltddat);
+	if (dodst)
+	    chipmem_agnus_wput (dstp, blt_info.bltddat);
 	blt_info.bltbhold = blitbhold;
     }
     blit_masktable[0] = 0xFFFF;
@@ -271,116 +266,109 @@ static void blitter_dofast_desc(void)
     bltstate = BLT_done;
 }
 
-STATIC_INLINE int blitter_read(void)
+STATIC_INLINE void blitter_read (void)
 {
-    if (bltcon0 & 0xe00){
-	if (!dmaen(DMA_BLITTER))
-	    return 1;
-	if (bltcon0 & 0x200) blt_info.bltcdat = chipmem_bank.wget(bltcpt);
+    if (bltcon0 & 0x200) {
+	if (!dmaen (DMA_BLITTER))
+	    return;
+	blt_info.bltcdat = chipmem_bank.wget (bltcpt);
     }
     bltstate = BLT_work;
-    return (bltcon0 & 0xE00) != 0;
 }
 
-STATIC_INLINE int blitter_write(void)
+STATIC_INLINE void blitter_write (void)
 {
-    if (blt_info.bltddat) blt_info.blitzero = 0;
-    if ((bltcon0 & 0x100) || blitline){
-	if (!dmaen(DMA_BLITTER)) return 1;
-	chipmem_bank.wput(bltdpt, blt_info.bltddat);
+    if (blt_info.bltddat)
+	blt_info.blitzero = 0;
+    /* D-channel state has no effect on linedraw, but C must be enabled or nothing is drawn! */
+    if (bltcon0 & 0x200) {
+	if (!dmaen (DMA_BLITTER))
+	    return;
+	chipmem_agnus_wput (bltdpt, blt_info.bltddat);
     }
     bltstate = BLT_next;
-    return (bltcon0 & 0x100) != 0;
 }
 
-STATIC_INLINE void blitter_line_incx(void)
+STATIC_INLINE void blitter_line_incx (void)
 {
     if (++blinea_shift == 16) {
 	blinea_shift = 0;
-	bltcnxlpt += 2;
-	bltdnxlpt += 2;
+	bltcpt += 2;
     }
 }
 
-STATIC_INLINE void blitter_line_decx(void)
+STATIC_INLINE void blitter_line_decx (void)
 {
     if (blinea_shift-- == 0) {
 	blinea_shift = 15;
-	bltcnxlpt -= 2;
-	bltdnxlpt -= 2;
+	bltcpt -= 2;
     }
 }
 
-STATIC_INLINE void blitter_line_decy(void)
+STATIC_INLINE void blitter_line_decy (void)
 {
-    bltcnxlpt -= blt_info.bltcmod;
-    bltdnxlpt -= blt_info.bltcmod; /* ??? am I wrong or doesn't KS1.3 set bltdmod? */
+    bltcpt -= blt_info.bltcmod;
     blitonedot = 0;
 }
 
-STATIC_INLINE void blitter_line_incy(void)
+STATIC_INLINE void blitter_line_incy (void)
 {
-    bltcnxlpt += blt_info.bltcmod;
-    bltdnxlpt += blt_info.bltcmod; /* ??? */
+    bltcpt += blt_info.bltcmod;
     blitonedot = 0;
 }
 
-static void blitter_line(void)
+static void blitter_line (void)
 {
-    uae_u16 blitahold = blinea >> blinea_shift;
+    uae_u16 blitahold = (blinea & blt_info.bltafwm) >> blinea_shift;
     uae_u16 blitbhold = blineb & 1 ? 0xFFFF : 0;
     uae_u16 blitchold = blt_info.bltcdat;
-    blt_info.bltddat = 0;
 
-    if (blitsing && blitonedot) blitahold = 0;
+    if (blitsing && blitonedot)
+	blitahold = 0;
     blitonedot = 1;
-    blt_info.bltddat = blit_func(blitahold, blitbhold, blitchold, bltcon0 & 0xFF);
-    if (!blitsign){
-	bltapt += (uae_s16)blt_info.bltamod;
-	if (bltcon1 & 0x10){
+    blt_info.bltddat = blit_func (blitahold, blitbhold, blitchold, bltcon0 & 0xFF);
+    if (!blitsign) {
+	if (bltcon0 & 0x800)
+	    bltapt += (uae_s16)blt_info.bltamod;
+	if (bltcon1 & 0x10) {
 	    if (bltcon1 & 0x8)
-		blitter_line_decy();
+		blitter_line_decy ();
 	    else
-		blitter_line_incy();
+		blitter_line_incy ();
 	} else {
 	    if (bltcon1 & 0x8)
-		blitter_line_decx();
+		blitter_line_decx ();
 	    else
-		blitter_line_incx();
+		blitter_line_incx ();
 	}
     } else {
-	bltapt += (uae_s16)blt_info.bltbmod;
+	if (bltcon0 & 0x800)
+	    bltapt += (uae_s16)blt_info.bltbmod;
     }
-    if (bltcon1 & 0x10){
+    if (bltcon1 & 0x10) {
 	if (bltcon1 & 0x4)
-	    blitter_line_decx();
+	    blitter_line_decx ();
 	else
-	    blitter_line_incx();
+	    blitter_line_incx ();
     } else {
 	if (bltcon1 & 0x4)
-	    blitter_line_decy();
+	    blitter_line_decy ();
 	else
-	    blitter_line_incy();
+	    blitter_line_incy ();
     }
     blitsign = 0 > (uae_s16)bltapt;
     bltstate = BLT_write;
 }
 
-STATIC_INLINE void blitter_nxline(void)
+STATIC_INLINE void blitter_nxline (void)
 {
-    bltcpt = bltcnxlpt;
-    bltdpt = bltdnxlpt;
     blineb = (blineb << 1) | (blineb >> 15);
-    if (--blt_info.vblitsize == 0) {
-	bltstate = BLT_done;
-    } else {
-	bltstate = BLT_read;
-    }
+    blt_info.vblitsize--;
+    bltstate = BLT_read;
 }
 
-static void blit_init(void)
+static void blit_init (void)
 {
-    blitlpos = 0;
     blt_info.blitzero = 1;
     blitline = bltcon1 & 1;
     blt_info.blitashift = bltcon0 >> 12;
@@ -392,8 +380,6 @@ static void blit_init(void)
 	if (blt_info.hblitsize != 2)
 	    write_log ("weird hblitsize in linemode: %d\n", blt_info.hblitsize);
 
-	bltcnxlpt = bltcpt;
-	bltdnxlpt = bltdpt;
 	blitsing = bltcon1 & 0x2;
 	blinea = blt_info.bltadat;
 	blineb = (blt_info.bltbdat >> blt_info.blitbshift) | (blt_info.bltbdat << (16-blt_info.blitbshift));
@@ -425,24 +411,29 @@ static void blit_init(void)
     }
 }
 
-static void actually_do_blit(void)
+static void actually_do_blit (void)
 {
     if (blitline) {
 	do {
-	    blitter_read();
-	    blitter_line();
-	    blitter_write();
-	    blitter_nxline();
+	    blitter_read ();
+	    blitter_line ();
+	    blitter_write ();
+	    bltdpt = bltcpt;
+	    blitter_nxline ();
+	    if (blt_info.vblitsize == 0)
+		bltstate = BLT_done;
+	    
 	} while (bltstate != BLT_done);
     } else {
-	/*blitcount[bltcon0 & 0xff]++;  blitter debug */
-	if (blitdesc) blitter_dofast_desc();
-	else blitter_dofast();
+	if (blitdesc)
+	    blitter_dofast_desc ();
+	else
+	    blitter_dofast ();
     }
     blitter_done_notify ();
 }
 
-void blitter_handler(void)
+void blitter_handler (void)
 {
     if (!dmaen(DMA_BLITTER)) {
 	eventtab[ev_blitter].active = 1;
@@ -450,7 +441,7 @@ void blitter_handler(void)
 	eventtab[ev_blitter].evtime = 10 * CYCLE_UNIT + get_cycles (); /* wait a little */
 	return; /* gotta come back later. */
     }
-    actually_do_blit();
+    actually_do_blit ();
 
     INTREQ(0x8040);
     eventtab[ev_blitter].active = 0;
@@ -463,7 +454,7 @@ static long blit_first_cycle;
 static int blit_last_cycle;
 static uae_u8 *blit_diag;
 
-void do_blitter(void)
+void do_blitter (void)
 {
     int ch = (bltcon0 & 0x0f00) >> 8;
     blit_diag = blit_cycle_diagram_start[ch];
