@@ -32,7 +32,6 @@
 #include <ctype.h>
 #include <assert.h>
 
-#include "config.h"
 #include "options.h"
 #include "threaddep/thread.h"
 #include "uae.h"
@@ -149,17 +148,19 @@ static int last_redraw_point;
 static int first_drawn_line, last_drawn_line;
 static int first_block_line, last_block_line;
 
+#define NO_BLOCK -3
+
 /* These are generated by the drawing code from the line_decisions array for
    each line that needs to be drawn.  These are basically extracted out of
    bit fields in the hardware registers.  */
-static int bplehb, bplham, bpldualpf, bpldualpfpri, bpldualpf2of, bplplanecnt, bplres;
+static int bplehb, bplham, bpldualpf, bpldualpfpri, bpldualpf2of, bplplanecnt;
+static int bplres, adjusted_bplres;
 static uae_u32 plf_sprite_mask;
 static int sbasecol[2];
 
 int picasso_requested_on;
 int picasso_on;
 
-uae_sem_t gui_sem;
 int inhibit_frame;
 
 int framecnt = 0;
@@ -488,13 +489,13 @@ static void pfield_do_linetoscr (int start, int stop)
 	    case 2: src_pixel = linetoscr_16_aga (src_pixel, start, stop); break;
 	    case 4: src_pixel = linetoscr_32_aga (src_pixel, start, stop); break;
 	    }
-	else if (res_shift == 1)
+	else if (res_shift > 0)
 	    switch (gfxvidinfo.pixbytes) {
 	    case 1: src_pixel = linetoscr_8_stretch1_aga (src_pixel, start, stop); break;
 	    case 2: src_pixel = linetoscr_16_stretch1_aga (src_pixel, start, stop); break;
 	    case 4: src_pixel = linetoscr_32_stretch1_aga (src_pixel, start, stop); break;
 	    }
-	else if (res_shift == -1)
+	else if (res_shift < 0)
 	    switch (gfxvidinfo.pixbytes) {
 	    case 1: src_pixel = linetoscr_8_shrink1_aga (src_pixel, start, stop); break;
 	    case 2: src_pixel = linetoscr_16_shrink1_aga (src_pixel, start, stop); break;
@@ -956,7 +957,7 @@ static void NOINLINE pfield_doline_n8 (uae_u32 *data, int count) { pfield_doline
 static void pfield_doline (int lineno)
 {
     int wordcount = dp_for_drawing->plflinelen;
-    uae_u32 *data = pixdata.apixels_l + MAX_PIXELS_PER_LINE/4;
+    uae_u32 *data = pixdata.apixels_l + MAX_PIXELS_PER_LINE / 4;
 
 #ifdef SMART_UPDATE
 #define DATA_POINTER(n) (line_data[lineno] + (n)*MAX_WORDS_PER_LINE*2)
@@ -1009,16 +1010,16 @@ static void init_aspect_maps (void)
     amiga2aspect_line_map = (int *)malloc (sizeof (int) * (MAXVPOS + 1)*2 + 1);
     native2amiga_line_map = (int *)malloc (sizeof (int) * gfxvidinfo.height);
 
-    if (currprefs.gfx_correct_aspect)
+    if (curr_gfx->correct_aspect)
 	native_lines_per_amiga_line = ((double)gfxvidinfo.height
-				       * (currprefs.gfx_lores ? 320 : 640)
-				       / (currprefs.gfx_linedbl ? 512 : 256)
+				       * (curr_gfx->lores ? 320 : 640)
+				       / (curr_gfx->linedbl ? 512 : 256)
 				       / gfxvidinfo.width);
     else
 	native_lines_per_amiga_line = 1;
 
-    maxl = (MAXVPOS + 1) * (currprefs.gfx_linedbl ? 2 : 1);
-    min_ypos_for_screen = minfirstline << (currprefs.gfx_linedbl ? 1 : 0);
+    maxl = (MAXVPOS + 1) * (curr_gfx->linedbl ? 2 : 1);
+    min_ypos_for_screen = minfirstline << (curr_gfx->linedbl ? 1 : 0);
     max_drawn_amiga_line = -1;
     for (i = 0; i < maxl; i++) {
 	int v = (int) ((i - min_ypos_for_screen) * native_lines_per_amiga_line);
@@ -1028,12 +1029,12 @@ static void init_aspect_maps (void)
 	    v = -1;
 	amiga2aspect_line_map[i] = v;
     }
-    if (currprefs.gfx_linedbl)
+    if (curr_gfx->linedbl)
 	max_drawn_amiga_line >>= 1;
 
-    if (currprefs.gfx_ycenter && !(currprefs.gfx_correct_aspect)) {
+    if (curr_gfx->ycenter && !(curr_gfx->correct_aspect)) {
 	/* @@@ verify maxvpos vs. MAXVPOS */
-	extra_y_adjust = (gfxvidinfo.height - (maxvpos << (currprefs.gfx_linedbl ? 1 : 0))) >> 1;
+	extra_y_adjust = (gfxvidinfo.height - (maxvpos << (curr_gfx->linedbl ? 1 : 0))) >> 1;
 	if (extra_y_adjust < 0)
 	    extra_y_adjust = 0;
     }
@@ -1045,7 +1046,7 @@ static void init_aspect_maps (void)
 	/* Must omit drawing some lines. */
 	for (i = maxl - 1; i > min_ypos_for_screen; i--) {
 	    if (amiga2aspect_line_map[i] == amiga2aspect_line_map[i-1]) {
-		if (currprefs.gfx_linedbl && (i & 1) == 0 && amiga2aspect_line_map[i+1] != -1) {
+		if (curr_gfx->linedbl && (i & 1) == 0 && amiga2aspect_line_map[i+1] != -1) {
 		    /* If only the first line of a line pair would be omitted,
 		     * omit the second one instead to avoid problems with line
 		     * doubling. */
@@ -1062,7 +1063,7 @@ static void init_aspect_maps (void)
 	if (amiga2aspect_line_map[i] == -1)
 	    continue;
 	for (j = amiga2aspect_line_map[i]; j < gfxvidinfo.height && native2amiga_line_map[j] == -1; j++)
-	    native2amiga_line_map[j] = i >> (currprefs.gfx_linedbl ? 1 : 0);
+	    native2amiga_line_map[j] = i >> (curr_gfx->linedbl ? 1 : 0);
     }
 }
 
@@ -1081,14 +1082,14 @@ static void do_flush_line_1 (int lineno)
 	flush_line (lineno);
     else {
 	if ((last_block_line+1) != lineno) {
-	    if (first_block_line != -2)
+	    if (first_block_line != NO_BLOCK)
 		flush_block (first_block_line, last_block_line);
 	    first_block_line = lineno;
 	}
 	last_block_line = lineno;
 	if (last_block_line - first_block_line >= gfxvidinfo.maxblocklines) {
 	    flush_block (first_block_line, last_block_line);
-	    first_block_line = last_block_line = -2;
+	    first_block_line = last_block_line = NO_BLOCK;
 	}
     }
 }
@@ -1110,7 +1111,7 @@ STATIC_INLINE void do_flush_screen (int start, int stop)
        Should be corrected.
        (sjo 26.9.99) */
 
-    if (gfxvidinfo.maxblocklines != 0 && first_block_line != -2) {
+    if (gfxvidinfo.maxblocklines != 0 && first_block_line != NO_BLOCK) {
 	flush_block (first_block_line, last_block_line);
     }
     unlockscr ();
@@ -1118,6 +1119,34 @@ STATIC_INLINE void do_flush_screen (int start, int stop)
 	flush_screen (start, stop);
 }
 
+/* We only save hardware registers during the hardware frame. Now, when
+ * drawing the frame, we expand the data into a slightly more useful
+ * form. */
+static void pfield_expand_dp_bplcon (void)
+{
+    int plf1pri, plf2pri;
+    bplres = dp_for_drawing->bplres;
+    bplplanecnt = dp_for_drawing->nr_planes;
+    bplham = dp_for_drawing->ham_at_start;
+
+    if (currprefs.chipset_mask & CSMASK_AGA) {
+	/* The KILLEHB bit exists in ECS, but is apparently meant for Genlock
+	 * stuff, and it's set by some demos (e.g. Andromeda Seven Seas) */
+	bplehb = ((dp_for_drawing->bplcon0 & 0xFCC0) == 0x6000 && !(dp_for_drawing->bplcon2 & 0x200));
+    } else {
+	bplehb = (dp_for_drawing->bplcon0 & 0xFC00) == 0x6000;
+    }
+    plf1pri = dp_for_drawing->bplcon2 & 7;
+    plf2pri = (dp_for_drawing->bplcon2 >> 3) & 7;
+    plf_sprite_mask = 0xFFFF0000 << (4 * plf2pri);
+    plf_sprite_mask |= (0xFFFF << (4 * plf1pri)) & 0xFFFF;
+    bpldualpf = (dp_for_drawing->bplcon0 & 0x400) == 0x400;
+    bpldualpfpri = (dp_for_drawing->bplcon2 & 0x40) == 0x40;
+    bpldualpf2of = (dp_for_drawing->bplcon3 >> 10) & 7;
+    sbasecol[0] = ((dp_for_drawing->bplcon4 >> 4) & 15) << 4;
+    sbasecol[1] = ((dp_for_drawing->bplcon4 >> 0) & 15) << 4;
+}
+
 static int drawing_color_matches;
 static enum { color_match_acolors, color_match_full } color_match_type;
 
@@ -1191,34 +1220,6 @@ STATIC_INLINE void do_color_changes (line_draw_func worker_border, line_draw_fun
     }
 }
 
-/* We only save hardware registers during the hardware frame. Now, when
- * drawing the frame, we expand the data into a slightly more useful
- * form. */
-static void pfield_expand_dp_bplcon (void)
-{
-    int plf1pri, plf2pri;
-    bplres = dp_for_drawing->bplres;
-    bplplanecnt = dp_for_drawing->nr_planes;
-    bplham = dp_for_drawing->ham_at_start;
-
-    if (currprefs.chipset_mask & CSMASK_AGA) {
-	/* The KILLEHB bit exists in ECS, but is apparently meant for Genlock
-	 * stuff, and it's set by some demos (e.g. Andromeda Seven Seas) */
-	bplehb = ((dp_for_drawing->bplcon0 & 0xFCC0) == 0x6000 && !(dp_for_drawing->bplcon2 & 0x200));
-    } else {
-	bplehb = (dp_for_drawing->bplcon0 & 0xFC00) == 0x6000;
-    }
-    plf1pri = dp_for_drawing->bplcon2 & 7;
-    plf2pri = (dp_for_drawing->bplcon2 >> 3) & 7;
-    plf_sprite_mask = 0xFFFF0000 << (4 * plf2pri);
-    plf_sprite_mask |= (0xFFFF << (4 * plf1pri)) & 0xFFFF;
-    bpldualpf = (dp_for_drawing->bplcon0 & 0x400) == 0x400;
-    bpldualpfpri = (dp_for_drawing->bplcon2 & 0x40) == 0x40;
-    bpldualpf2of = (dp_for_drawing->bplcon3 >> 10) & 7;
-    sbasecol[0] = ((dp_for_drawing->bplcon4 >> 4) & 15) << 4;
-    sbasecol[1] = ((dp_for_drawing->bplcon4 >> 0) & 15) << 4;
-}
-
 enum double_how {
     dh_buf,
     dh_line,
@@ -1288,8 +1289,8 @@ STATIC_INLINE void pfield_draw_line (int lineno, int gfx_ypos, int follow_ypos)
     if (border == 0) {
 	pfield_expand_dp_bplcon ();
 
-	if (bplres == RES_LORES && ! currprefs.gfx_lores)
-	    currprefs.gfx_lores = 2;
+	if (bplres == RES_LORES && ! curr_gfx->lores)
+	    curr_gfx->lores = 2;
 
 	pfield_init_linetoscr ();
 	pfield_doline (lineno);
@@ -1333,8 +1334,8 @@ STATIC_INLINE void pfield_draw_line (int lineno, int gfx_ypos, int follow_ypos)
 		memcpy (row_map[follow_ypos], row_map[gfx_ypos], gfxvidinfo.pixbytes * gfxvidinfo.width);
 	    do_flush_line (follow_ypos);
 	}
-	if (currprefs.gfx_lores == 2)
-	    currprefs.gfx_lores = 0;
+	if (curr_gfx->lores == 2)
+	    curr_gfx->lores = 0;
     } else if (border == 1) {
 	adjust_drawing_colors (dp_for_drawing->ctable, 0);
 
@@ -1389,8 +1390,8 @@ static void center_image (void)
     int prev_x_adjust = visible_left_border;
     int prev_y_adjust = thisframe_y_adjust;
 
-    if (currprefs.gfx_xcenter) {
-	if (max_diwstop - min_diwstart < gfxvidinfo.width && currprefs.gfx_xcenter == 2)
+    if (curr_gfx->xcenter) {
+	if (max_diwstop - min_diwstart < gfxvidinfo.width && curr_gfx->xcenter == 2)
 	    /* Try to center. */
 	    visible_left_border = ((max_diwstop - min_diwstart - gfxvidinfo.width) / 2 + min_diwstart) & ~1;
 	else
@@ -1398,7 +1399,7 @@ static void center_image (void)
 
 	/* Would the old value be good enough? If so, leave it as it is if we want to
 	 * be clever. */
-	if (currprefs.gfx_xcenter == 2) {
+	if (curr_gfx->xcenter == 2) {
 	    if (visible_left_border < prev_x_adjust && prev_x_adjust < min_diwstart)
 		visible_left_border = prev_x_adjust;
 	}
@@ -1414,14 +1415,14 @@ static void center_image (void)
 	visible_right_border = max_diwlastword;
 
     thisframe_y_adjust = minfirstline;
-    if (currprefs.gfx_ycenter && thisframe_first_drawn_line != -1) {
-	if (thisframe_last_drawn_line - thisframe_first_drawn_line < max_drawn_amiga_line && currprefs.gfx_ycenter == 2)
+    if (curr_gfx->ycenter && thisframe_first_drawn_line != -1) {
+	if (thisframe_last_drawn_line - thisframe_first_drawn_line < max_drawn_amiga_line && curr_gfx->ycenter == 2)
 	    thisframe_y_adjust = (thisframe_last_drawn_line - thisframe_first_drawn_line - max_drawn_amiga_line) / 2 + thisframe_first_drawn_line;
 	else
 	    thisframe_y_adjust = thisframe_first_drawn_line;
 	/* Would the old value be good enough? If so, leave it as it is if we want to
 	 * be clever. */
-	if (currprefs.gfx_ycenter == 2) {
+	if (curr_gfx->ycenter == 2) {
 	    if (thisframe_y_adjust != prev_y_adjust
 		&& prev_y_adjust <= thisframe_first_drawn_line
 		&& prev_y_adjust + max_drawn_amiga_line > thisframe_last_drawn_line)
@@ -1433,13 +1434,13 @@ static void center_image (void)
 	if (thisframe_y_adjust < minfirstline)
 	    thisframe_y_adjust = minfirstline;
     }
-    thisframe_y_adjust_real = thisframe_y_adjust << (currprefs.gfx_linedbl ? 1 : 0);
-    max_ypos_thisframe = (maxvpos - thisframe_y_adjust) << (currprefs.gfx_linedbl ? 1 : 0);
+    thisframe_y_adjust_real = thisframe_y_adjust << (curr_gfx->linedbl ? 1 : 0);
+    max_ypos_thisframe = (maxvpos - thisframe_y_adjust) << (curr_gfx->linedbl ? 1 : 0);
 
     /* @@@ interlace_seen used to be (bplcon0 & 4), but this is probably
      * better.  */
     if (prev_x_adjust != visible_left_border || prev_y_adjust != thisframe_y_adjust)
-	frame_redraw_necessary |= interlace_seen && currprefs.gfx_linedbl ? 2 : 1;
+	frame_redraw_necessary |= interlace_seen && curr_gfx->linedbl ? 2 : 1;
 
     max_diwstop = 0;
     min_diwstart = 10000;
@@ -1456,7 +1457,10 @@ static void init_drawing_frame (void)
     if (thisframe_first_drawn_line > thisframe_last_drawn_line)
 	thisframe_last_drawn_line = thisframe_first_drawn_line;
 
-    maxline = currprefs.gfx_linedbl ? (maxvpos+1) * 2 + 1 : (maxvpos+1) + 1;
+    if (!curr_gfx)
+	return;
+
+    maxline = curr_gfx->linedbl ? (maxvpos+1) * 2 + 1 : (maxvpos+1) + 1;
 #ifdef SMART_UPDATE
     for (i = 0; i < maxline; i++) {
 	switch (linestate[i]) {
@@ -1476,7 +1480,7 @@ static void init_drawing_frame (void)
     last_drawn_line = 0;
     first_drawn_line = 32767;
 
-    first_block_line = last_block_line = -2;
+    first_block_line = last_block_line = NO_BLOCK;
     if (currprefs.test_drawing_speed)
 	frame_redraw_necessary = 1;
     else if (frame_redraw_necessary)
@@ -1510,22 +1514,23 @@ static int td_pos = (TD_RIGHT|TD_BOTTOM);
 
 #define TD_TOTAL_HEIGHT (TD_PADY * 2 + TD_NUM_HEIGHT)
 
-#define NUMBERS_NUM 14
+#define NUMBERS_NUM 16
 
-static char *numbers = { /* ugly */
-"+++++++--++++-+++++++++++++++++-++++++++++++++++++++++++++++++++++++++++++++-++++++-++++----++---+"
-"+xxxxx+--+xx+-+xxxxx++xxxxx++x+-+x++xxxxx++xxxxx++xxxxx++xxxxx++xxxxx++xxxx+-+x++x+-+xxx++-+xx+-+x"
-"+x+++x+--++x+-+++++x++++++x++x+++x++x++++++x++++++++++x++x+++x++x+++x++x++++-+x++x+-+x++x+--+x++x+"
-"+x+-+x+---+x+-+xxxxx++xxxxx++xxxxx++xxxxx++xxxxx+--++x+-+xxxxx++xxxxx++x+----+xxxx+-+x++x+----+x+-"
-"+x+++x+---+x+-+x++++++++++x++++++x++++++x++x+++x+--+x+--+x+++x++++++x++x++++-+x++x+-+x++x+---+x+x+"
-"+xxxxx+---+x+-+xxxxx++xxxxx+----+x++xxxxx++xxxxx+--+x+--+xxxxx++xxxxx++xxxx+-+x++x+-+xxx+---+x++xx"
-"+++++++---+++-++++++++++++++----+++++++++++++++++--+++--++++++++++++++++++++-++++++-++++----------"
+#define TD_BORDER 0x333
+
+static const char *numbers = { /* ugly  0123456789CHD%+- */
+"+++++++--++++-+++++++++++++++++-++++++++++++++++++++++++++++++++++++++++++++-++++++-++++----++---+--------------"
+"+xxxxx+--+xx+-+xxxxx++xxxxx++x+-+x++xxxxx++xxxxx++xxxxx++xxxxx++xxxxx++xxxx+-+x++x+-+xxx++-+xx+-+x---+----------"
+"+x+++x+--++x+-+++++x++++++x++x+++x++x++++++x++++++++++x++x+++x++x+++x++x++++-+x++x+-+x++x+--+x++x+--+x+----+++--"
+"+x+-+x+---+x+-+xxxxx++xxxxx++xxxxx++xxxxx++xxxxx+--++x+-+xxxxx++xxxxx++x+----+xxxx+-+x++x+----+x+--+xxx+--+xxx+-"
+"+x+++x+---+x+-+x++++++++++x++++++x++++++x++x+++x+--+x+--+x+++x++++++x++x++++-+x++x+-+x++x+---+x+x+--+x+----+++--"
+"+xxxxx+---+x+-+xxxxx++xxxxx+----+x++xxxxx++xxxxx+--+x+--+xxxxx++xxxxx++xxxx+-+x++x+-+xxx+---+x++xx--------------"
+"+++++++---+++-++++++++++++++----+++++++++++++++++--+++--++++++++++++++++++++-++++++-++++------------------------"
 };
 
 STATIC_INLINE void putpixel (int x, xcolnr c8)
 {
-    switch(gfxvidinfo.pixbytes)
-    {
+    switch (gfxvidinfo.pixbytes) {
     case 1:
 	xlinebuffer[x] = (uae_u8)c8;
 	break;
@@ -1579,7 +1584,8 @@ static void draw_status_line (int line)
     memset (xlinebuffer, 0, gfxvidinfo.width * gfxvidinfo.pixbytes);
 
     for (led = 0; led < 5; led++) {
-	int side, pos, num1 = -1, num2 = -1, num3 = -1, num4 = -1, x, off_rgb, on_rgb, c, on = 0;
+	int side, pos, num1 = -1, num2 = -1, num3 = -1, num4 = -1;
+	int x, off_rgb, on_rgb, c, on = 0;
 	if (led > 0) {
 	    int pled = led - 1;
 	    int track = gui_data.drive_track[pled];
@@ -1602,23 +1608,29 @@ static void draw_status_line (int line)
 	    off_rgb = 0x300;
 	}
 	c = xcolors[on ? on_rgb : off_rgb];
+	if (y == 0 || y == TD_TOTAL_HEIGHT - 1)
+	    c = xcolors[TD_BORDER];
 
 	x = x_start + pos * TD_WIDTH;
+	putpixel (x - 1, xcolors[TD_BORDER]);
 	for (j = 0; j < TD_LED_WIDTH; j++)
 	    putpixel (x + j, c);
+	putpixel (x + j, xcolors[TD_BORDER]);
 
 	if (y >= TD_PADY && y - TD_PADY < TD_NUM_HEIGHT) {
 	    if (num3 >= 0) {
 		int tn = num1 > 0 ? 3 : 2;
-		int offs = (TD_LED_WIDTH - tn * TD_NUM_WIDTH) / 2;
+		x += (TD_LED_WIDTH - tn * TD_NUM_WIDTH) / 2;
 		if (num1 > 0) {
-		    write_tdnumber (x + offs, y - TD_PADY, num1);
-		    offs += TD_NUM_WIDTH;
+		    write_tdnumber (x, y - TD_PADY, num1);
+		    x += TD_NUM_WIDTH;
 		}
-		write_tdnumber (x + offs, y - TD_PADY, num2);
-		write_tdnumber (x + offs + TD_NUM_WIDTH, y - TD_PADY, num3);
+		write_tdnumber (x, y - TD_PADY, num2);
+		x += TD_NUM_WIDTH;
+		write_tdnumber (x, y - TD_PADY, num3);
+		x += TD_NUM_WIDTH;
 		if (num4 > 0)
-		    write_tdnumber (x + offs + 2 * TD_NUM_WIDTH, y - TD_PADY, num4);
+		    write_tdnumber (x, y - TD_PADY, num4);
 	    }
 	}
     }
@@ -1650,14 +1662,14 @@ void finish_drawing_frame (void)
 	    break;
 
 	where = amiga2aspect_line_map[i1];
-	if (where >= gfxvidinfo.height - (currprefs.leds_on_screen ? TD_TOTAL_HEIGHT : 0))
+	if (where >= gfxvidinfo.height - (curr_gfx->leds_on_screen ? TD_TOTAL_HEIGHT : 0))
 	    break;
 	if (where == -1)
 	    continue;
 
 	pfield_draw_line (line, where, amiga2aspect_line_map[i1 + 1]);
     }
-    if (currprefs.leds_on_screen) {
+    if (curr_gfx->leds_on_screen) {
 	for (i = 0; i < TD_TOTAL_HEIGHT; i++) {
 	    int line = gfxvidinfo.height - TD_TOTAL_HEIGHT + i;
 	    draw_status_line (line);
@@ -1708,6 +1720,56 @@ STATIC_INLINE void check_picasso (void)
 #endif
 }
 
+int check_prefs_changed_gfx (void)
+{
+    int params_changed = 0, screen_changed = 0;
+    int old_x, old_y;
+
+    if (!screen_is_picasso) {
+	if (curr_gfx == &currprefs.gfx_w
+	    && memcmp (&changed_prefs.gfx_w, &currprefs.gfx_w, sizeof (struct gfx_params)) != 0)
+	{
+	    old_x = currprefs.gfx_w.width;
+	    old_y = currprefs.gfx_w.height;
+	    fixup_prefs_dimensions (&changed_prefs.gfx_w, gfx_windowed_modes, n_windowed_modes);
+	    currprefs.gfx_w = changed_prefs.gfx_w;
+	    params_changed = 1;
+	    screen_changed = (old_x != currprefs.gfx_w.width
+			      || old_y != currprefs.gfx_w.height);
+	} else if (curr_gfx == &currprefs.gfx_f
+		   && memcmp (&changed_prefs.gfx_f, &currprefs.gfx_f, sizeof (struct gfx_params)) != 0)
+	{
+	    old_x = currprefs.gfx_f.width;
+	    old_y = currprefs.gfx_f.height;
+	    fixup_prefs_dimensions (&changed_prefs.gfx_f, gfx_fullscreen_modes, n_fullscreen_modes);
+	    currprefs.gfx_f = changed_prefs.gfx_f;
+	    params_changed = 1;
+	    screen_changed = (old_x != currprefs.gfx_f.width
+			      || old_y != currprefs.gfx_f.height);
+	}
+	if (changed_prefs.gfx_afullscreen != currprefs.gfx_afullscreen) {
+	    screen_changed = 1;
+	}
+    } else if (changed_prefs.gfx_pfullscreen != currprefs.gfx_pfullscreen) {
+	screen_changed = 1;
+    }
+
+    currprefs.gfx_afullscreen = changed_prefs.gfx_afullscreen;
+    currprefs.gfx_pfullscreen = changed_prefs.gfx_pfullscreen;
+
+    if (screen_changed) {
+	graphics_subshutdown (0);
+
+	gui_update_gfx ();
+
+	graphics_subinit ();
+
+	reset_drawing ();
+    }
+
+    return params_changed || screen_changed;
+}
+
 void vsync_handle_redraw (int long_frame, int lof_changed)
 {
     last_redraw_point++;
@@ -1745,14 +1807,20 @@ void vsync_handle_redraw (int long_frame, int lof_changed)
 	count_frame ();
 	check_picasso ();
 
+	currprefs.keyboard_lang = changed_prefs.keyboard_lang;
 	check_prefs_changed_audio ();
 	check_prefs_changed_custom ();
 	check_prefs_changed_cpu ();
 	if (check_prefs_changed_gfx ()) {
-	    init_row_map ();
-	    init_aspect_maps ();
+	    if (curr_gfx) {
+		init_row_map ();
+		init_aspect_maps ();
+	    }
 	    notice_screen_contents_lost ();
 	    notice_new_xcolors ();
+
+	    if (screen_is_picasso)
+		picasso_enablescreen (1);
 	}
 
 	if (inhibit_frame != 0)
@@ -1810,19 +1878,12 @@ void reset_drawing (void)
 {
     int i;
 
-    inhibit_frame = 0;
-    uae_sem_init (&gui_sem, 0, 1);
-
-#ifdef PICASSO96
-    InitPicasso96 ();
-    picasso_on = 0;
-    picasso_requested_on = 0;
-    gfx_set_picasso_state (0);
-#endif
     max_diwstop = 0;
 
-    lores_factor = currprefs.gfx_lores ? 1 : 2;
-    lores_shift = currprefs.gfx_lores ? 0 : 1;
+    if (!curr_gfx)
+	return;
+    lores_factor = curr_gfx->lores ? 1 : 2;
+    lores_shift = curr_gfx->lores ? 0 : 1;
 
     /*memset(blitcount, 0, sizeof(blitcount));  blitter debug */
     for (i = 0; i < sizeof linestate / sizeof *linestate; i++)
@@ -1845,12 +1906,24 @@ void reset_drawing (void)
     init_drawing_frame ();
 }
 
+void init_drawing_at_reset (void)
+{
+    InitPicasso96 ();
+    picasso_requested_on = 0;
+    picasso_on = 0;
+    gfx_set_picasso_state (0);
+
+    inhibit_frame = 0;
+}
+
 void drawing_init ()
 {
+    inhibit_frame = 0;
+
     native2amiga_line_map = 0;
     amiga2aspect_line_map = 0;
     line_drawn = 0;
 
-    gen_pfield_tables();
+    gen_pfield_tables ();
 }
 
