@@ -11,7 +11,7 @@ extern void CIA_vsync_handler (void);
 extern void CIA_hsync_handler (void);
 extern void CIA_handler (void);
 
-extern void diskindex_handler (void);
+extern void cia_diskindex (void);
 
 extern void dumpcia (void);
 extern void rethink_cias (void);
