@@ -6,26 +6,26 @@
   * Copyright 1996 Bernd Schmidt
   */
 
-static __inline__ uae_u32 do_get_mem_long(uae_u32 *a)
+STATIC_INLINE uae_u32 do_get_mem_long(uae_u32 *a)
 {
     uae_u8 *b = (uae_u8 *)a;
 
     return (*b << 24) | (*(b+1) << 16) | (*(b+2) << 8) | (*(b+3));
 }
 
-static __inline__ uae_u16 do_get_mem_word(uae_u16 *a)
+STATIC_INLINE uae_u16 do_get_mem_word(uae_u16 *a)
 {
     uae_u8 *b = (uae_u8 *)a;
 
     return (*b << 8) | (*(b+1));
 }
 
-static __inline__ uae_u8 do_get_mem_byte(uae_u8 *a)
+STATIC_INLINE uae_u8 do_get_mem_byte(uae_u8 *a)
 {
     return *a;
 }
 
-static __inline__ void do_put_mem_long(uae_u32 *a, uae_u32 v)
+STATIC_INLINE void do_put_mem_long(uae_u32 *a, uae_u32 v)
 {
     uae_u8 *b = (uae_u8 *)a;
 
@@ -35,7 +35,7 @@ static __inline__ void do_put_mem_long(uae_u32 *a, uae_u32 v)
     *(b+3) = v;
 }
 
-static __inline__ void do_put_mem_word(uae_u16 *a, uae_u16 v)
+STATIC_INLINE void do_put_mem_word(uae_u16 *a, uae_u16 v)
 {
     uae_u8 *b = (uae_u8 *)a;
 
@@ -43,7 +43,7 @@ static __inline__ void do_put_mem_word(uae_u16 *a, uae_u16 v)
     *(b+1) = v;
 }
 
-static __inline__ void do_put_mem_byte(uae_u8 *a, uae_u8 v)
+STATIC_INLINE void do_put_mem_byte(uae_u8 *a, uae_u8 v)
 {
     *a = v;
 }
