@@ -1,15 +1,14 @@
- /* 
+ /*
   * UAE - The Un*x Amiga Emulator
-  * 
+  *
   * Support for Mac OS sound
-  * 
+  *
   * Copyright 1996 Ernesto Corvi
   */
 
 #include "sysconfig.h"
 #include "sysdeps.h"
 
-#include "config.h"
 #include "options.h"
 #include "memory.h"
 #include "custom.h"
@@ -35,8 +34,8 @@ void close_sound(void)
 }
 
 int init_sound (void)
-{	
-    if (SndNewChannel(&newChannel, sampledSynth, initMono, NULL)) 
+{
+    if (SndNewChannel(&newChannel, sampledSynth, initMono, NULL))
 	return 0;
     sndbufsize = 44100;
     init_sound_table8 ();
