@@ -11,7 +11,7 @@ extern uae_u16 *sndbuffer;
 extern uae_u16 *sndbufpt;
 extern int sndbufsize;
 
-__inline__ void check_sound_buffers (void);
+extern int check_sound_buffers (void);
 
 #define PUT_SOUND_BYTE(b) do { *(uae_u8 *)sndbufpt = b; sndbufpt = (uae_u16 *)(((uae_u8 *)sndbufpt) + 1); } while (0)
 #define PUT_SOUND_WORD(b) do { *(uae_u16 *)sndbufpt = b; sndbufpt = (uae_u16 *)(((uae_u8 *)sndbufpt) + 2); } while (0)
