@@ -1039,7 +1039,7 @@ static void unacquire_mouse (unsigned int num)
    return;
 }
 
-static unsigned int get_mouse_num (void)
+static int get_mouse_num (void)
 {
     return 1;
 }
@@ -1049,7 +1049,7 @@ static const char *get_mouse_name (unsigned int mouse)
     return "Default mouse";
 }
 
-static unsigned int get_mouse_widget_num (unsigned int mouse)
+static int get_mouse_widget_num (unsigned int mouse)
 {
     return MAX_AXES + MAX_BUTTONS;
 }
@@ -1100,7 +1100,7 @@ struct inputdevice_functions inputdevicefunc_mouse = {
 /*
  * Keyboard inputdevice functions
  */
-static unsigned int get_kb_num (void)
+static int get_kb_num (void)
 {
     /* SDL supports only one keyboard */
     return 1;
@@ -1111,7 +1111,7 @@ static const char *get_kb_name (unsigned int kb)
     return "Default keyboard";
 }
 
-static unsigned int get_kb_widget_num (unsigned int kb)
+static int get_kb_widget_num (unsigned int kb)
 {
     return 255; // fix me
 }
