@@ -6,8 +6,8 @@
   * Copyright 1997, 2001 Bernd Schmidt
   */
 
-#include "SDL.h"
-#include "SDL_thread.h"
+#include <SDL.h>
+#include <SDL_thread.h>
 
 /* Sempahores. We use POSIX semaphores; if you are porting this to a machine
  * with different ones, make them look like POSIX semaphores. */
@@ -27,10 +27,16 @@ typedef SDL_sem *uae_sem_t;
 typedef SDL_Thread *uae_thread_id;
 #define BAD_THREAD NULL
 
-static __inline__ int uae_start_thread (void *(*f) (void *), void *arg, uae_thread_id *foo)
+STATIC_INLINE int uae_start_thread (void *(*f) (void *), void *arg, uae_thread_id *thread)
 {
-    *foo = SDL_CreateThread ((int (*)(void *))f, arg);
-    return *foo == 0;
+    *thread = SDL_CreateThread ((int (*)(void *))f, arg);
+    return *thread == 0;
+}
+
+STATIC_INLINE int uae_wait_thread (uae_thread_id thread)
+{
+    SDL_WaitThread (thread, (int*)0);
+    return 0;
 }
 
 /* Do nothing; thread exits if thread function returns.  */
